@@ -18,7 +18,8 @@ from api_dnl import settings
 from api_dnl.resources import check_context, DnlResource,DnlList, ValidationError, DnlCreate, CustomGetAction, CustomPostAction, \
     CustomDeleteAction
 from api_dnl.schemes.shaken import *
-from api_dnl.scheme import SendCdrDirectScheme, ObjectCreatedMultipleScheme, ShakenStiSpConfScheme, ShakenStiSpConfSchemeModify
+from api_dnl.scheme import SendCdrDirectScheme, ObjectCreatedMultipleScheme, ShakenStiSpConfScheme, ShakenStiSpConfSchemeModify, \
+    ShakenStiSpConfSchemeGet
 from api_dnl.view import DEFAULT_SECURITY, OperationErrorResponse
 import json
 from api_dnl.views.report import Report
@@ -443,7 +444,7 @@ class ShakenStiSpConfCreate(DnlCreate):
 class ShakenStiSpConfResource(DnlResource):
     model_class = model.ShakenStiSpConf
     scheme_class = ShakenStiSpConfScheme
-    scheme_class_get = ShakenStiSpConfScheme
+    scheme_class_get = ShakenStiSpConfSchemeGet
     scheme_class_modify = ShakenStiSpConfSchemeModify
     entity = 'ShakenStiSpConf'
     id_field = 'id'
@@ -507,7 +508,7 @@ class ShakenStiSpConfResource(DnlResource):
 
 
 class ShakenStiSpConfList(DnlList):
-    scheme_class = ShakenStiSpConfScheme
+    scheme_class = ShakenStiSpConfSchemeGet
     model_class = model.ShakenStiSpConf
     entity_plural = 'ShakenStiSpConfs'
     path_parameters = ()
